<?php
// WizyTówka 4
if (!defined('WT')) exit();


// funkcje modyfikujące ciągi znaków

function tekst( $tekst, $uzywacMarkdown = false ) {

	if ( $uzywacMarkdown and odczytKonf('sposobEdycjiTekstu') == 'jezykMarkdown' and odczytKonf('jezykMarkdown') ) {

		include_once('markdown.php');

		$tekst = Markdown($tekst);

	}

	if ( odczytKonf('typografiaInne') ) {

		$m = 'm';
		if ( odczytKonf('typografiaPolpauza') )
			$m = 'n';

		$inneZnaki = array(
			' - '  => ' &'.$m.'dash; ', '>- ' => '>&'.$m.'dash; ', ' -<' => ' &'.$m.'dash;<',// myślnik/pauza
			'... ' => '&hellip; ', ' ...' => ' &hellip;', "...\n" => "&hellip;\n", "\n..." => "\n&hellip;",
			'>...' => '>&hellip;', '...<' => '&hellip;<',         // wielokropek
			"'" => '&rsquo;'     // apostrof - najbardziej wadliwy fragment
		);

		$tekst = zastepowanie( $tekst, $inneZnaki );

	}

	if ( odczytKonf('typografiaCudzyslowy') ) {

		$cudzyslowy = array(
			' "' => ' &bdquo;', '>"' => '>&bdquo;', '("' => '(&bdquo;',     // cudzysłów otwierający
			'" ' => '&rdquo; ', '"<' => '&rdquo;<', '")' => '&rdquo;)',     // cudzysłów zamykający
			'",' => '&rdquo;,', '";' => '&rdquo;;', '"!' => '&rdquo;!', '"?' => '&rdquo;?', '".' => '&rdquo;.'
		);

		$tekst = str_replace( '&quot;', '"', $tekst );

		preg_match_all ( '/>[^>]*</i', $tekst, $fragmentyHTML );
			//  podziękowania za pomoc dla soanviga   http://webax.pl/zamiana-na-t270/#entry2427

		if ( !empty($fragmentyHTML[0]) ) {
			foreach ( $fragmentyHTML as $fragment )
				$tekst = str_replace( $fragment, zastepowanie($fragment,$cudzyslowy), $tekst );
		}
		else
			$tekst = trim( zastepowanie( ' '.$tekst.' ', $cudzyslowy ) );

	}

	if ( odczytKonf('typografiaSpojniki') ) {

		$spojniki = array(
			'(a ' => '(a&nbsp;', '(i ' => '(i&nbsp;', '(o ' => '(o&nbsp;', '(u ' => '(u&nbsp;', '(w ' => '(w&nbsp;', '(z ' => '(z&nbsp;',
			' a ' => ' a&nbsp;', ' i ' => ' i&nbsp;', ' o ' => ' o&nbsp;', ' u ' => ' u&nbsp;', ' w ' => ' w&nbsp;', ' z ' => ' z&nbsp;',
			' A ' => ' A&nbsp;', ' I ' => ' I&nbsp;', ' O ' => ' O&nbsp;', ' U ' => ' U&nbsp;', ' W ' => ' W&nbsp;', ' Z ' => ' Z&nbsp;',
		);

		$tekst = zastepowanie( $tekst, $spojniki );

	}

	return $tekst;

}

function pokazDate ( $czasUniksowy, $formatDaty = null ) {

	if ( !is_numeric($czasUniksowy) )
		return false;

	if ( empty($formatDaty) )
		$formatDaty = odczytKonf('formatDaty');

	return date( $formatDaty, $czasUniksowy );

}

function sprawdzAdres ( $ciag ) {

	if ( empty($ciag) )
		return false;
	return preg_match ( '/^(http|https)\:\/\/[a-zA-Z0-9\.\-_\/:]+$/' , $ciag );

}

function sprawdzEmail ( $ciag ) {

	if ( empty($ciag) )
		return false;
	return preg_match ( '/^[a-zA-Z0-9\.\-_]+@[a-zA-Z0-9\.\-_]+\.[a-zA-Z0-9\.\-_]{2,4}$/' , $ciag );

}

function sprawdzNazwe ( $ciag ) {

	if ( empty($ciag) or $ciag[0] == '.' or is_numeric($ciag) )
		return false;
	return preg_match ( '/^[a-zA-Z0-9\.\-\_]+$/' , $ciag );

}

function prostaNazwa ( $ciag, $maleLitery = true ) {

	if ( empty($ciag) )
		return '-';

	$znakiDiakrytyczne = array(
		'ą' => 'a', 'ć' => 'c', 'ę' => 'e', 'ł' => 'l', 'ń' => 'n', 'ś' => 's', 'ó' => 'o', 'ż' => 'z', 'ź' => 'z',
		'Ą' => 'A', 'Ć' => 'C', 'Ę' => 'E', 'Ł' => 'L', 'Ń' => 'N', 'Ś' => 'S', 'Ó' => 'O', 'Ż' => 'Z', 'Ź' => 'Z'
	);
	$ciag = zastepowanie( $ciag, $znakiDiakrytyczne );

	$znakiSpecialne = array(
		',', '/', "'", '"', "\\", '!', '?', '@', '$', '%', '&', '*',
		'(', ')', '[', ']', '<', '>', '{', '}', '=', '+', ':', ';'
	);
	$ciag  = str_replace( $znakiSpecialne, null, $ciag );

	$ciag  = str_replace( ' ', '-', $ciag );

	if ( $maleLitery )
		$ciag = strtolower( $ciag );

	return $ciag;

}

function zastepowanie ( $tekst, $tablicaZastepowania ) {

	foreach ( $tablicaZastepowania as $oryginal => $zamiennik )
		$tekst = str_replace( $oryginal, $zamiennik, $tekst );

	return $tekst;

}

function usunRozszerzenie ( $nazwaPliku ) {

	return substr( $nazwaPliku, 0, strrpos($nazwaPliku,'.',true) );

}

function sortowanie ( $tablicaDoPosortowania, $elementSortujacy, $odwrocenie = false ) {

	foreach ( $tablicaDoPosortowania as $klucz => $zawartosc )
		$tablicaRobocza[$klucz] = $zawartosc[$elementSortujacy];

	if ( !is_numeric($zawartosc[$elementSortujacy]) )
		asort( $tablicaRobocza, SORT_LOCALE_STRING );
	else
		asort( $tablicaRobocza );

	foreach ( $tablicaRobocza as $klucz => $posortowanaWartosc )
		$tablicaPosortowana[$klucz] = $tablicaDoPosortowania[$klucz];

	if ( $odwrocenie )
		return array_reverse( $tablicaPosortowana, true );
	else
		return $tablicaPosortowana;

}

function fragment( $ciag, $iloscZnakow ) {

	if ( mb_strlen($ciag) > $iloscZnakow )
		$ciag = trim( mb_substr( $ciag, 0, $iloscZnakow ) ) . '…';

	return $ciag;

}
